@@ -11,11 +11,11 @@ __all__ = ['sites2seq', 'seq2sites', 'sites2str']
 # we fall back to direct import.
 try:
     from oldowan.mitomotifs.sites2seq import sites2seq
-    from oldowan.mitomotifs.sites2seq import sites_from_string
+    from oldowan.mitomotifs.str2sites import str2sites
     from oldowan.mitomotifs.seq2sites import seq2sites
     from oldowan.mitomotifs.sites2str import sites2str
 except:
     from sites2seq import sites2seq
-    from sites2seq import sites_from_string
+    from str2sites import str2sites
     from seq2sites import seq2sites
     from sites2str import sites2str
